%define _serverbuild_flags -fstack-protector-all

Name:           dnsmasq
Version:        2.91
Release:        %mkrel 1
Summary:        A lightweight DHCP/caching DNS server
License:        GPLv2 or GPLv3
Group:          System/Servers
URL:            https://www.thekelleys.org.uk/dnsmasq/
Source0:        https://www.thekelleys.org.uk/dnsmasq/%{name}-%{version}.tar.xz
Source1:        %{name}.service

BuildRequires:          pkgconfig(dbus-1)
BuildRequires:          pkgconfig(libidn2)
BuildRequires:          pkgconfig(libnetfilter_conntrack)
BuildRequires:          pkgconfig(nettle)

Requires(pre):          rpm-helper
Requires(preun):        rpm-helper
Requires(post):         rpm-helper
Requires(postun):       rpm-helper

Obsoletes:              %{name}-base < 2.78-3

%description
Dnsmasq is lightweight, easy to configure DNS forwarder and DHCP server.
It is designed to provide DNS and, optionally, DHCP, to a small network.
It can serve the names of local machines which are not in the global
DNS. The DHCP server integrates with the DNS server and allows machines
with DHCP-allocated addresses to appear in the DNS with names configured
either in each host or in a central configuration file. Dnsmasq supports
static and dynamic DHCP leases and BOOTP for network booting of diskless
machines.

%package        utils
Summary:        Utilities for manipulating DHCP server leases
Group:          System/Servers

%description    utils
Utilities that use the standard DHCP protocol to
query/remove a DHCP server's leases.

%prep
%setup -q
%autopatch -p1

# fix the path to the trust anchor
sed -i 's|%%%%PREFIX%%%%|%{_prefix}|' dnsmasq.conf.example

#set default user /group in src/config.h
sed -i 's|#define CHUSER "nobody"|#define CHUSER "dnsmasq"|' src/config.h
sed -i 's|#define CHGRP "dip"|#define CHGRP "dnsmasq"|' src/config.h

# use /run instead of /var/run
sed -i 's|/var/run|%{_rundir}|g' $(grep -rl --exclude=CHANGELOG* /var/run)

# don't run build again with install
sed -i 's/^install-i18n.*i18n/install-i18n :/' Makefile

%build
%make_build all-i18n V=1 \
        CFLAGS="%{optflags}" \
        LDFLAGS="%{ldflags}" \
        PREFIX=%{_prefix} \
        COPTS="-DHAVE_DNSSEC -DHAVE_CONNTRACK -DHAVE_DBUS -DHAVE_LIBIDN2"
%make_build -C contrib/lease-tools CFLAGS="%{optflags}"

%install
# we don't want to run %%make_install as we want to use install-i18n target
%__make install-i18n PREFIX=%{_prefix} DESTDIR=%{?buildroot}

%__install -Dpm644 dnsmasq.conf.example %{buildroot}%{_sysconfdir}/dnsmasq.conf

%__install -Dpm755 contrib/lease-tools/dhcp_release %{buildroot}%{_bindir}/dhcp_release
%__install -Dpm644 contrib/lease-tools/dhcp_release.1 %{buildroot}%{_mandir}/man1/dhcp_release.1
%__install -Dpm755 contrib/lease-tools/dhcp_release6 %{buildroot}%{_bindir}/dhcp_release6
%__install -Dpm644 contrib/lease-tools/dhcp_release6.1 %{buildroot}%{_mandir}/man1/dhcp_release6.1
%__install -Dpm755 contrib/lease-tools/dhcp_lease_time %{buildroot}%{_bindir}/dhcp_lease_time
%__install -Dpm644 contrib/lease-tools/dhcp_lease_time.1 %{buildroot}%{_mandir}/man1/dhcp_lease_time.1

# Dnssec
%__install -Dpm644 trust-anchors.conf %{buildroot}%{_datadir}/%{name}/trust-anchors.conf

# Systemd
mkdir -p %{buildroot}%{_unitdir}
install -m644 %{SOURCE1} %{buildroot}%{_unitdir}
rm -rf %{buildroot}%{_initrddir}

%find_lang %{name} --with-man

%pre
%_pre_useradd %{name} /dev/null /sbin/nologin

%post
%_post_service dnsmasq

%preun
%_preun_service dnsmasq

%files -f %{name}.lang
%doc CHANGELOG COPYING COPYING-v3 FAQ doc.html setup.html dbus/DBus-interface
%config(noreplace) %{_sysconfdir}/dnsmasq.conf
%{_unitdir}/%{name}.service
%{_sbindir}/dnsmasq
%{_mandir}/man8/dnsmasq.8*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/trust-anchors.conf

%files utils
%{_bindir}/dhcp_*
%{_mandir}/man1/dhcp_*


%changelog
* Sun Mar 23 2025 julien <julien> 2.91-1.mga10
+ Revision: 2169188
- new version 2.91

* Wed Feb 14 2024 julien <julien> 2.90-1.mga10
+ Revision: 2041306
- new version 2.90
- drop merged patch0

* Sat Apr 15 2023 julien <julien> 2.89-2.mga9
+ Revision: 1953021
- add patch to set the default maximum DNS UDP packet size to 1232, MGA#31770

* Sun Feb 05 2023 julien <julien> 2.89-1.mga9
+ Revision: 1938586
- new version 2.89

* Mon Dec 05 2022 julien <julien> 2.88-1.mga9
+ Revision: 1918283
- new version 2.88

* Sat Nov 12 2022 julien <julien> 2.87-2.mga9
+ Revision: 1906535
- correct service name for post and preun macros
+ wally <wally>
- drop empty %%postun scriptlet

* Mon Sep 26 2022 julien <julien> 2.87-1.mga9
+ Revision: 1892555
- new version 2.87
- drop patch0, merged upstream

* Thu Apr 21 2022 julien <julien> 2.86-3.mga9
+ Revision: 1852549
- add patch for CVE-2022-0934, MGA#30318, write after free in DHCPv6 code

* Sat Mar 26 2022 umeabot <umeabot> 2.86-2.mga9
+ Revision: 1827785
- Mageia 9 Mass Rebuild

* Thu Sep 09 2021 julien <julien> 2.86-1.mga9
+ Revision: 1744867
- new version 2.86

* Thu Apr 08 2021 julien <julien> 2.85-1.mga9
+ Revision: 1714134
- new version 2.85

* Tue Jan 19 2021 neoclust <neoclust> 2.83-1.mga8
+ Revision: 1672551
- New version 2.83 - Fixes CVE-2020-2568[1-7] (mga#28169)

* Sun Nov 29 2020 luigiwalser <luigiwalser> 2.82-2.mga8
+ Revision: 1650420
- rebuild for nettle

* Mon Jul 20 2020 julien <julien> 2.82-1.mga8
+ Revision: 1607384
- new version 2.82

* Sun Jul 19 2020 julien <julien> 2.81-2.mga8
+ Revision: 1607233
- add local-service option to cmdline.
  	With it, dnsmasq listen only to local subnet; see also
  	bug MGA#26964 (CVE-2020-14312).
  	This option only has effect if there are no
  		--interface,
  		--except-interface,
  		--listen-address or
  		--auth-server options
  	on cmdline or in dnsmasq.conf (without the double dash)

* Mon Apr 13 2020 julien <julien> 2.81-1.mga8
+ Revision: 1567111
- new version 2.81
- drop merged patch

* Tue Feb 18 2020 umeabot <umeabot> 2.80-11.mga8
+ Revision: 1539792
- Mageia 8 Mass Rebuild

* Fri Dec 13 2019 tmb <tmb> 2.80-10.mga8
+ Revision: 1466267
- fix CVE-2019-14834 (mga#25854)
- properly fix SIOCGSTAMP support with newer kernels

* Mon Dec 09 2019 tmb <tmb> 2.80-9.mga8
+ Revision: 1465547
- drop artificial conflict on bind

* Thu Nov 07 2019 pterjan <pterjan> 2.80-8.mga8
+ Revision: 1458695
- rebuild for new nettle on armv7hl

* Tue Oct 01 2019 daviddavid <daviddavid> 2.80-7.mga8
+ Revision: 1448564
- rebuild for new nettle 3.5.1

* Tue Aug 20 2019 daviddavid <daviddavid> 2.80-6.mga8
+ Revision: 1430685
- add patch to fix build with new glibc
- add patch to fix build build with nettle 3.5

* Sun Feb 17 2019 wally <wally> 2.80-5.mga7
+ Revision: 1368079
- save pid file to /run instead of /var/run

* Wed Feb 13 2019 luigiwalser <luigiwalser> 2.80-4.mga7
+ Revision: 1366525
- rebuild for libidn2

* Wed Jan 09 2019 wally <wally> 2.80-3.mga7
+ Revision: 1353596
- rebuild for new libidn2
+ tmb <tmb>
- revert last commit, there is no base package anymore
- add/remove dnsmasq user belongs to base package

* Sun Oct 21 2018 julien <julien> 2.80-2.mga7
+ Revision: 1323298
- fix homedir for dnsmasq user
- drop mention of sysconfig file, we don't carry it anymore

* Sat Oct 20 2018 julien <julien> 2.80-1.mga7
+ Revision: 1323144
- new version 2.80
- dnsmasq now run as user dnsmasq instead of nobody (MGA#22694)

* Sun Sep 23 2018 umeabot <umeabot> 2.79-2.mga7
+ Revision: 1297474
- Mageia 7 Mass Rebuild

* Thu Mar 22 2018 julien <julien> 2.79-1.mga7
+ Revision: 1211326
- new version 2.79
- drop patch0&1 merged

* Thu Feb 01 2018 wally <wally> 2.78-4.mga7
+ Revision: 1198429
- use versioned obsoletes for dnsmasq-base

* Wed Jan 31 2018 julien <julien> 2.78-3.mga7
+ Revision: 1198328
- add patch to fix CVE-2017-15107 (MGA#22494): improper validation of wildcard synthesized NSEC records
- fix dnssec configution (add trust-anchors.conf in our package)
- merge dnsmasq-base in main dnsmasq package

* Thu Oct 12 2017 wally <wally> 2.78-2.mga7
+ Revision: 1171278
- switch to libidn2
- enable DNSSEC

* Mon Oct 02 2017 julien <julien> 2.78-1.mga7
+ Revision: 1163571
- new version 2.78
- drop merged patch0

* Sun Oct 01 2017 julien <julien> 2.77-2.mga7
+ Revision: 1162163
- Fix CVE-2017-13704, which resulted in a crash on a large DNS query (mga#21793)

* Fri Jun 02 2017 julien <julien> 2.77-1.mga6
+ Revision: 1105861
- new version 2.77
- drop merged patch

* Tue May 02 2017 julien <julien> 2.76-4.mga6
+ Revision: 1098692
- Restore PIDFile option in systemd unit. Seems to be necessary for systemd to properly remove pidfile when stopping dnsmasq. (mga#20766)

* Mon Mar 27 2017 wally <wally> 2.76-3.mga6
+ Revision: 1094970
- use our build time flags (for real)
- enable IDN and i18n support
- enable conntrack support

* Tue Oct 04 2016 luigiwalser <luigiwalser> 2.76-2.mga6
+ Revision: 1058617
- add upstream patches to fix issues found by mozilla security audit

* Fri May 27 2016 julien <julien> 2.76-1.mga6
+ Revision: 1018989
- new version 2.76
- fix build for tools & filelist
- adjust update message as we don't carry sysconfig file anymore

* Wed May 25 2016 tv <tv> 2.75-3.mga6
+ Revision: 1018282
- add a %%postun with std systemd macro
- use std systemd macros
- fix a path in dnsmasq.conf (rhbz#1295143)
- sync systemd service with FC (but keep our options handling)
- do not ship sysconfig script when we already ship systemd seervice

* Thu Feb 11 2016 umeabot <umeabot> 2.75-2.mga6
+ Revision: 953794
- Mageia 6 Mass Rebuild

* Mon Aug 17 2015 julien <julien> 2.75-1.mga6
+ Revision: 865375
- new version 2.75

* Sun Jul 19 2015 julien <julien> 2.73-1.mga6
+ Revision: 855216
- new version 2.73

* Tue May 05 2015 julien <julien> 2.71-4.mga5
+ Revision: 821279
- add rediffed upstream patch to fix CVE-2015-3294 (MGA#15855)

* Wed Oct 15 2014 umeabot <umeabot> 2.71-3.mga5
+ Revision: 739076
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.71-2.mga5
+ Revision: 678779
- Mageia 5 Mass Rebuild

* Sun May 18 2014 julien <julien> 2.71-1.mga5
+ Revision: 623620
- new version 2.71

* Tue Apr 29 2014 julien <julien> 2.70-1.mga5
+ Revision: 618899
- new version 2.70

* Wed Mar 26 2014 julien <julien> 2.68-1.mga5
+ Revision: 608833
- new version 2.68

* Sat Oct 19 2013 umeabot <umeabot> 2.66-3.mga4
+ Revision: 531644
- Mageia 4 Mass Rebuild

* Wed Aug 07 2013 joequant <joequant> 2.66-2.mga4
+ Revision: 464380
- check group
- add dnsmasq-utils to match fedora

* Thu Jun 20 2013 julien <julien> 2.66-1.mga4
+ Revision: 445287
- new version 2.66

* Thu Jan 31 2013 julien <julien> 2.65-3.mga3
+ Revision: 393849
- add patch from redhat to fix CVE-2013-0198

* Fri Jan 11 2013 umeabot <umeabot> 2.65-2.mga3
+ Revision: 349042
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Dec 14 2012 julien <julien> 2.65-1.mga3
+ Revision: 331001
- new version 2.65
- remove initscript as mga3 is systemd only

* Thu Dec 06 2012 julien <julien> 2.64-1.mga3
+ Revision: 327523
- update to new version 2.64

* Tue Aug 21 2012 julien <julien> 2.63-1.mga3
+ Revision: 282947
- new version 2.63

* Fri Jun 08 2012 julien <julien> 2.62-1.mga3
+ Revision: 257965
- new version 2.62

* Mon Jun 04 2012 julien <julien> 2.61-1.mga3
+ Revision: 254453
- update to version 2.61
- add systemd unit file
- add a warning on update when using sysconfig file

* Fri Oct 21 2011 julien <julien> 2.59-1.mga2
+ Revision: 157280
- update to version 2.59

* Thu Oct 06 2011 julien <julien> 2.58-1.mga2
+ Revision: 152534
- new version 2.58
- small cleanup of specfile

* Sat Apr 16 2011 misc <misc> 2.57-1.mga1
+ Revision: 86170
- update to 2.57
- remove and clean old conflict

* Thu Jan 27 2011 erwan <erwan> 2.55-1.mga1
+ Revision: 42235
- imported package dnsmasq

